@@ -32,9 +32,7 @@ class NotificationStack(Stack):
 
         pinpoint_app = pinpoint.CfnApp(self, pinpoint_app_name, name=pinpoint_app_name) 
         print(apns_certificate)
-        print(apns_private_key)
-
-        directory_asset = Asset(self, "CERT", path="/Users/m1pro/Downloads/Certificates.cer")
+        print(apns_private_key) 
 
 
         cfn_aPNSSandbox_channel = pinpoint.CfnAPNSSandboxChannel(self, "{}-apns-sandbox".format(pinpoint_app_name),
@@ -42,10 +40,10 @@ class NotificationStack(Stack):
 
             # the properties below are optional
             bundle_id=apns_bundle_id,
-            certificate=directory_asset,
+            certificate=apns_certificate,
             default_authentication_method="certificate", 
-            enabled=True,
-            private_key=apns_private_key,
+            enabled=False,
+            # private_key=apns_private_key,
             # team_id="teamId",
             # token_key="tokenKey",
             # token_key_id="tokenKeyId"
